@@ -37,7 +37,7 @@ class TQPainter;
  */
 class URLButton : public TQPushButton
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
